@@ -1,21 +1,17 @@
-#######################################################################
-## cronbach - funcion del paquete multilevel
-## Package: multilevel
-## Version: 2.5
-## License: GPL (>= 2)
-## <environment: namespace:multilevel>
 
 #######################################################################
 #' @name alpha.cronbach
-#' @title alpha.cronbach
+#' @title Cronbach's alpha
 #' @description Cronbach's alpha measures how correlated are the items in a test
-#' License :GPL (>= 2) Extracted from multilevel_2.5 package
-#' @usage alpha.cronbach(test)
 #' @param test a matrix or a Dataframe that holds the test response data
-#' @details the coefficient is calculated $\alpha = (n/n-1)*(1 - (\sum V_i/V_t))$
+#' @details the coefficient is calculated \deqn{\alpha = (n/n-1)*(1 - (\sum V_i/V_t))}
 #' where $V_t$ is the variance of test scores and $V_i$ is the variance of item scores.
 #' It is desirable that the items are closely interrelated (coefficient near 1).
-#' @return Cronbach's alpha for the test.
+#' This function was extracted from multilevel_2.5 package.
+#' @return Cronbach's alpha for the test and the number of individuals of test.
+#' @examples
+#' data <- simulateTest(model="2PL",items=10,individuals=1000)
+#' alpha.cronbach(data$test)
 #' @references Cronbach L. J. (1951) Coefficient Alpha and the internal structure of tests. Psychometrika, 16,297-334
 #' @export
 
@@ -30,71 +26,10 @@ alpha.cronbach <- function (test)
   return(OUT)
 }
 
-#######################################################################
-#### Coeficiente de correlacion biserial
-## biserial.cor funcion del paquete ltm
-## Package: ltm 
-## Version:	 1.0-0
-## License:	GPL
-## <environment: namespace:ltm>  
-
-#######################################################################
-#' @name biserial.cor
-#' @title biserial.cor
-#' @description Point-Biserial correlation coefficient is a correlation coefficient
-#' used when one variable is continuous and the other variable is dichotomous.
-#' License :GPL Adapted from ltm_1.0 package
-#' @usage biserial.cor(x,y, use = c("all.obs", "complete.obs"), level = 1)
-#' @param x a numeric vector representing the continuous variable. 
-#' @param y a numeric vector representing the dichotomous variable.
-#' @param use Is a option for the use of missing values. 
-#' @param level which level of y to use.
-#' @details It is calculated by applying the Pearson correlation coefficient to the case
-#' where one of the variables has dichotomous nature. 
-#' It is calculated as $r_{xy} = (\bar{x}_p - \bar{x}_q / S_x)*\sqrt{pq}$ 
-#' where p  is the proportion of subjects with one of the two possible values of the 
-#' variable Y, q is the proportion of subjects with the other possible value, 
-#' $\bar{x}_p$ and $\bar{x}_q$ is the average X subjects whose proportion is p and q respectively,
-#' and $S_x$ is the standard deviation of all subjects X.
-#' @return the value of the point-biserial correlation.
-#' @references U.Olsson, F.Drasgow, and N.Dorans (1982). The polyserial correlation coefficient. Psychometrika, 47:337-347.
-#' @references Cox. N.R. (1974). Estimation of the Correlation between a Continuous and a Discrete Variable. Biometrics, 30:171-178.
-#' @export
-
-biserial.cor <- function (x, y, use = c("all.obs", "complete.obs"), level = 1) 
-{
-  if (!is.numeric(x)) 
-    stop("'x' must be a numeric variable.\n")
-  y <- as.factor(y)
-  if (length(levs <- levels(y)) > 2) 
-    stop("'y' must be a dichotomous variable.\n")
-  if (length(x) != length(y)) 
-    stop("'x' and 'y' do not have the same length")
-  use <- match.arg(use)
-  if (use == "complete.obs") {
-    cc.ind <- complete.cases(x, y)
-    x <- x[cc.ind]
-    y <- y[cc.ind]
-  }
-  ind <- y == levs[level]
-  diff.mu <- mean(x[ind]) - mean(x[!ind])
-  prob <- mean(ind)
-  diff.mu * sqrt(prob * (1 - prob))/sd(x)
-}
-
-#######################################################################
-## Curva de Cronbach-Mesbah
-## Package:	 CMC
-## Version:	 1.0
-## License:	 GPL (>= 2)
-## <environment: namespace:CMC>
-
 #######################################################################
 #' @name alpha.c
 #' @title Cronbach-Mesbah Curve
 #' @description To assess the unidimensionality of a set of items from alpha coefficient.
-#' License :GPL (>= 2) Extracted from CMC_1.0 package
-#' @usage alpha.c(test)
 #' @param test a Dataframe that holds the test response data
 #' @details To construct the curve takes the next step by step:
 #' 1. The first step uses all items to compute alpha. 
@@ -102,10 +37,14 @@ biserial.cor <- function (x, y, use = c("all.obs", "complete.obs"), level = 1)
 #' with its maximum alpha value. If we remove a bad item, the alpha  coefficient  will
 #' increase, whereas if we remove a good item alpha must decrease.  
 #' 3. This procedure is repeated until only  two items remain.
+#' This function was extracted from CMC_1.0 package.
 #' @return The number of items used to calculate the coefficient. 
 #' @return The maximum value of the alpha coefficient calculated at each step. 
 #' @return The item removed at each step. 
 #' @return Tue Cronbach-Mesbah curve plot.
+#' @examples
+#' data <- simulateTest(model="2PL",items=10,individuals=1000)
+#' curve <- alpha.c(data$test)
 #' @references Cameletti, M. & Caviezel, V. (2010). Checking the unidimensionality in R
 #' using the Cronbach-Mesbah curve.
 #' @references Mesbah, M. (2010). Statistical quality of life. In "Method and Applications of Statistics in the 
@@ -157,30 +96,74 @@ alpha.c <- function (test) {
   return(output)
 }
 
-################################################################################
-## Informacion del test
-## information funcion del paquete ltm
-## Package: ltm 
-## Version:	 1.0-0
-## License:	GPL
-## <environment: namespace:ltm>  
+#######################################################################
+#' @name biserial.cor
+#' @title Biserial Correlation
+#' @description Point-Biserial correlation coefficient is a correlation coefficient
+#' used when one variable is continuous and the other variable is dichotomous.
+#' @param x a numeric vector representing the continuous variable. 
+#' @param y a numeric vector representing the dichotomous variable.
+#' @param use Is a option for the use of missing values. 
+#' @param level which level of y to use.
+#' @details It is calculated by applying the Pearson correlation coefficient to the case
+#' where one of the variables has dichotomous nature. 
+#' It is calculated as \deqn{r_{xy} = (\bar{x}_p - \bar{x}_q / S_x)*\sqrt{pq}}
+#' where p  is the proportion of subjects with one of the two possible values of the 
+#' variable Y, q is the proportion of subjects with the other possible value, 
+#' \deqn{\bar{x}_p} and \deqn{\bar{x}_q} is the average X subjects whose proportion is p and q respectively,
+#' and $S_x$ is the standard deviation of all subjects X.
+#' This function was adapted from ltm_1.0 package.
+#' @examples 
+#' data <- simulateTest(model="2PL",items=10,individuals=1000)
+#' biserial.cor(rowSums(data$test), data$test[,1])
+#' @return The value of the point-biserial correlation.
+#' @references U.Olsson, F.Drasgow, and N.Dorans (1982). The polyserial correlation coefficient. Psychometrika, 47:337-347.
+#' @references Cox. N.R. (1974). Estimation of the Correlation between a Continuous and a Discrete Variable. Biometrics, 30:171-178.
+#' @export
+
+biserial.cor <- function (x, y, use = c("all.obs", "complete.obs"), level = 1) 
+{
+  if (!is.numeric(x)) 
+    stop("'x' must be a numeric variable.\n")
+  y <- as.factor(y)
+  if (length(levs <- levels(y)) > 2) 
+    stop("'y' must be a dichotomous variable.\n")
+  if (length(x) != length(y)) 
+    stop("'x' and 'y' do not have the same length")
+  use <- match.arg(use)
+  if (use == "complete.obs") {
+    cc.ind <- complete.cases(x, y)
+    x <- x[cc.ind]
+    y <- y[cc.ind]
+  }
+  ind <- y == levs[level]
+  diff.mu <- mean(x[ind]) - mean(x[!ind])
+  prob <- mean(ind)
+  diff.mu * sqrt(prob * (1 - prob))/sd(x)
+}
+
 
 #######################################################################
 #' @name information 
 #' @title Test or Item information
 #' @description Computes the amount of test or item information. 
-#' License :GPL (>= 2) Adapted from ltm_1.0 package
-#' @usage information(object, range, items = NULL)
 #' @param object a matrix  (con los coeficientes estimados)
 #' @param range a interval for which the test information should be computed.
 #' @param items the items for which the information shoulb be computed.
 #' @details The amount of information is computed as the area under the Item or Test
 #' Information Curve. 
+#' The function was adapted from ltm_1.0 package.
 #' @return TotalInfo the total amount of information.
 #' @return RangeInfo the amount of information in the specified interval.
 #' @return RangeProp the proportion of information in the specified interval.
 #' @return Range the value of range argument
 #' @return items the value of items argument
+#' @examples
+#' #data <- simulateTest(model = "2PL", items = 20, individuals = 800) 
+#' #fit <- irtpp(dataset = data$test,model = "2PL")
+#' #fit <- parameter.matrix(fit$z)
+#' #information(fit, c(-2, 0))
+#' #information(fit, c(0, 2), items = c(3, 5))
 #' @references Reckase, M. (2009). Multidimensional item response theory. New York: Springer.
 #' @references Baker, F. B., & Kim, S. H. (Eds.). (2004). Item response theory: Parameter estimation techniques. CRC Press.
 #' @export
@@ -224,26 +207,28 @@ information <- function (object, range, items = NULL) {
 #' @name gutt
 #' @title Guttman's Lambda
 #' @description Six Lower limits of reliability coefficients are presented. 
-#' @usage gutt(test)
 #' @param test a matrix or a Dataframe that holds the test response data
-#' @details Let S_j^2 the variances over persons of the n items in the test, and
-#' S_t^2 the variance over persons of the sum of the items.
-#' The firt estimate lambda_1 can be computed from L_1 = 1 - (sum{s_j^2}/S_t^2)
-#' Let C_2 the sum of squares of the covariances between items, therefore is
-#' the sum of n(n-1)/2 terms. The bound lambda_2 is computed by L_2 = L_1 + (sqrt{n/n-1 C_2}/S_t^2) 
-#' The third lower bound lambda_3 is a modification of lambda_1, it is computed
-#' from the L_3 = n/(n-1) L_1
-#' Fourth lower bound lamda_4 has been interpreted as the greatest split half reliability,
+#' @details Let $S_j^2$ the variances over persons of the n items in the test, and
+#' $S_t^2$ the variance over persons of the sum of the items.
+#' The firt estimate $lambda_1$ can be computed from $L_1 = 1 - (sum{s_j^2}/S_t^2)$
+#' Let $C_2$ the sum of squares of the covariances between items, therefore is
+#' the sum of $n(n-1)/2$ terms. The bound $lambda_2$ is computed by $L_2 = L_1 + (sqrt{n/n-1 C_2}/S_t^2)$ 
+#' The third lower bound $lambda_3$ is a modification of $lambda_1$, it is computed
+#' from the $L_3 = n/(n-1) L_1$
+#' Fourth lower bound $lamda_4$ has been interpreted as the greatest split half reliability,
 #' and requires that the test be scored as twohalves. It is calculated from 
-#' L_4 = 2(1 - (s_a^2 + s_b^2)/s_t^2) where S_a^2 and S_b^2 are the respectives variances
+#' $L_4 = 2(1 - (s_a^2 + s_b^2)/s_t^2)$ where $S_a^2$ and $S_b^2$ are the respectives variances
 #' of the two parts for the single trial. 
-#' For the fifth lower bound lambda_5, let C_{2j} be the sum of the squares of the
-#' covariances of item j with the remaining n-1 items, and let bar{C}_2 be the largest of
-#' the C_{2j}. Then the coefficient can be computed from L_5 = L_1 + (2sqrt{bar{C}_2})/S_t^2
-#' The final bound is based on multiple correlation, let e_j^2 be the variance of the errors
+#' For the fifth lower bound $lambda_5$, let $C_{2j}$ be the sum of the squares of the
+#' covariances of item j with the remaining $n-1$ items, and let $bar{C}_2$ be the largest of
+#' the $C_{2j}$. Then the coefficient can be computed from $L_5 = L_1 + (2sqrt{bar{C}_2})/S_t^2$
+#' The final bound is based on multiple correlation, let $e_j^2$ be the variance of the errors
 #' of estimate of item j from its linear multiple regression on the remaining n-1 items. Then
-#' lambda_6 can be computed from L_6 = 1 - (sum{e_j^2})/S_t^2 
+#' $lambda_6$ can be computed from $L_6 = 1 - (sum{e_j^2})/S_t^2$ 
 #' @return The six coefficients Guttman for the test.
+#' @examples 
+#' #data <- simulateTest(model="2PL",items=10,individuals=1000)
+#' #gutt(data$test) 
 #' @references Guttman, L. (1945). A basis for analyzing test-retest reliability. Psychometrika, 10(4), 255-282.
 #' @export
 
@@ -323,17 +308,20 @@ gutt <- function(test){
 #' @title Yule coefficient of correlation 
 #' @description The Yule coefficient of is  a correlation coefficient applied 
 #' to dichotomous data. Given a two x two table of counts
-#' a  b  R1
-#' c  d  R2
-#' C1 C2 n
+#' | a | b | R1 |
+#' | c | d | R1 |
+#' |---|---|----|
+#' |C1 | C2| n  |
 #' or a vector c(a,b,c,d) of frequencies.
-#' @usage Yule(x, Y = FALSE)
 #' @param x a 1 x 4 vector or a matrix 2 x 2 of frequencies.
 #' @param Y if Y is true return Yule's Y coefficient of colligation.
 #' @details The coefficient of Yule is calculated from (ad - bc)/(ad + bc).
 #' This is the number of pairs in agreement (ad) - the number in disagreement (bc) 
 #' over the total number of paired observations. 
 #' @return the value of the Yule Q coefficient.
+#' @examples 
+#' #x <- c(12,8,16,9)
+#' #Yule(x)
 #' @references Yule, G.U. (1912). On the methods of measuring the association between two attributes. Journal of the Royal Statistical Society, 75, 579-652.
 #' @references Warrens, Matthijs (2008), On Association Coefficients for 2x2 Tables and Properties That Do Not Depend on the Marginal Distributions. Psychometrika, 73, 777-789.
 #' @export
@@ -358,19 +346,22 @@ Yule <- function (x, Y = FALSE)
 }
 
 #######################################################################
-#' @name Phi
+#' @name phi
 #' @title Phi coefficient of correlation 
 #' @description The phi coefficient of is  a correlation coefficient applied 
 #' to dichotomous data. Given a two x two table of counts
-#' a  b  R1
-#' c  d  R2
-#' C1 C2 n
+#' | a | b | R1 |
+#' | c | d | R1 |
+#' |---|---|----|
+#' |C1 | C2| n  |
 #' or a vector c(a,b,c,d) of frequencies.
-#' @usage phi(x)
 #' @param x a 1 x 4 vector or a matrix 2 x 2 of frequencies.
-#' @details The coefficient phi is calculated from $(ad - bc)/\sqrt{p_qp_2q_1q_2}$ 
+#' @details The coefficient phi is calculated from \deqn{(ad - bc)/\sqrt{p_qp_2q_1q_2}}
 #' where $p_i$ and $q_i$ are the ratios of the dichotomous variables. 
 #' @return the value of the phi coefficient correlation.
+#' @examples
+#' #x2 <- matrix(x,ncol=2)
+#' #phi(x2)
 #' @references Warrens, Matthijs (2008), On Association Coefficients for 2x2 Tables and Properties That Do Not Depend on the Marginal Distributions. Psychometrika, 73, 777-789.
 #' @references Yule, G.U. (1912). On the methods of measuring the association between two attributes. Journal of the Royal Statistical Society, 75, 579-652.
 #' @export
@@ -393,55 +384,55 @@ phi <- function (x)
 
 #######################################################################
 #' @name polyserial.cor
-#' @title polyserial.cor
+#' @title Polyserial correlation
 #' @description Polyserial correlation coefficient is a correlation coefficient
 #' used when one variable is continuous and the other variable is dichotomous.
-#' License :GPL Adapted from ltm_1.0 package
-#' @usage polyserial.cor(x,y)
 #' @param x a numeric vector representing the continuous variable. 
 #' @param y a numeric vector representing the dichotomous variable.
-#' @details The coefficient is calculated from $\rho = r_{xy} * \sqrt{(n - 1)/n} * s_y/\sum{\phi(\tau)}$ 
+#' @details The coefficient is calculated from \deqn{\rho = r_{xy} * \sqrt{(n - 1)/n} * s_y/\sum{\phi(\tau)}}
 #' where $r_{xy}$ is the coefficient of correlation of Pearson coefficient, S_y is the 
-#' standard deviation of Y, and $\phi(\tau)$ are the ordinates of the normal curve at 
+#' standard deviation of Y, and \deqn{\phi(\tau)} are the ordinates of the normal curve at 
 #' the normal equivalent of the cut point boundaries between the item responses.
+#' This function was adapted from ltm_1.0 package.
+#' @examples
+#'  x <- rnorm(100)
+#'  y <- sample(1:5,100,replace=TRUE)
+#'  cor(x, y) 
+#'  polyserial.cor(x, y) 
 #' @return the value of the polyserial correlation.
 #' @references U.Olsson, F.Drasgow, and N.Dorans (1982). The polyserial correlation coefficient. Psychometrika, 47:337-347.
 #' @export
 
 polyserial.cor <- function (x, y) 
 {
-  min.item <- min(y, na.rm = TRUE) #Busca el minimo
-  max.item <- max(y, na.rm = TRUE) #Busca el maximo
+  min.item <- min(y, na.rm = TRUE) 
+  max.item <- max(y, na.rm = TRUE) 
+  n.var <- 1  
+  n.cases <- length(y) 
   
-  #Si y es un vector
-  n.var <- 1  #Numero de variables
-  n.cases <- length(y) #Numero de obs
-  
-  dummy <- matrix(rep(min.item:max.item, n.var), ncol = n.var, nrow=length(y)) #Matriz de trabajo
-  colnames(dummy) <- names(y) #Nombres de columnas de matriz
-  xdum <- cbind(y, dummy) #Matriz y y matriz de trabajo
-  frequency <- apply(xdum, 2, table) #Vuelve las tablas frecuencias
-  frequency <- t(frequency - 1) # Transpone las frecuencias
-  responses <- rowSums(frequency) #Numero de respuestas
-  frequency <- frequency/responses #proporciones
-  frequency <- t(apply(frequency, 1, cumsum)) #Sumas acumuladas
+  dummy <- matrix(rep(min.item:max.item, n.var), ncol = n.var, nrow=length(y))
+  colnames(dummy) <- names(y) 
+  xdum <- cbind(y, dummy) 
+  frequency <- apply(xdum, 2, table) 
+  frequency <- t(frequency - 1) 
+  responses <- rowSums(frequency) 
+  frequency <- frequency/responses 
+  frequency <- t(apply(frequency, 1, cumsum)) 
   len <- dim(frequency)[2] 
-  tau <- dnorm(qnorm(frequency[, -len, drop = FALSE])) #Valores de densidad de la variable y
-  stau <- rowSums(tau) #Sumas sobre densidad
-  rxy <- cor(x, y, use = "pairwise") #Correlacion entre x y y
-  sdy <- sd(y) #Desviacion estandar por columnas de y
-  rps <- t(rxy) * sqrt((n.cases - 1)/n.cases) * sdy/stau[1] #Correlacion poliserial
+  tau <- dnorm(qnorm(frequency[, -len, drop = FALSE])) 
+  stau <- rowSums(tau) 
+  rxy <- cor(x, y, use = "pairwise") 
+  sdy <- sd(y) 
+  rps <- t(rxy) * sqrt((n.cases - 1)/n.cases) * sdy/stau[1] 
   rps[rps > 1] <- 1
   rps[rps < -1] <- -1
   return(rps)
 }
 
-#######################################################################
 #######################################################################
 #' @name an.parallel
 #' @title Parallel Analysis
 #' @description performs Horn's parallel analysis for a principal component. 
-#' @usage an.parallel(x = NA, iterations = 0, centile = 0, seed = 0,mat = NA, n = NA)
 #' @param x a matrix or a Dataframe that holds the test response data
 #' @param iterations a number indicating the amount of iterations that 
 #' representing the number of random data sets to be produced in the analysis.
@@ -460,6 +451,9 @@ polyserial.cor <- function (x, y)
 #' @return Unadjusted eigenvalues a vector of the eigenvalues of the observed data from either
 #' an unrotated principal component analysis.
 #' @return Bias a vector of the estimated bias of the unadjusted eigenvalues 
+#' @examples 
+#' data <- simulateTest(model="2PL",items=10,individuals=1000) 
+#' an.parallel(data$test, iterations = 100, centile = 99, seed = 12)
 #' @references John L. Horn (1965). A rationale and test for the number of factors 
 #' in factor analysis. Psychometrika, Volume 30, Number 2, Page 179.
 #' @references Dinno A. 2009. Exploring the Sensitivity of Horn's Parallel Analysis to the 
@@ -469,9 +463,6 @@ polyserial.cor <- function (x, y)
 an.parallel <- function(x = NA, iterations = 0, centile = 0, seed = 0, 
                         mat = NA, n = NA) 
 {
-  ### Verificacin de las matrices x y mat - si es x entonces son los datos, 
-  ### si es mat es una matriz de correlaci?n
-  
   if (!is.na(mat[[1]][1]) & !is.na(x[[1]][1])) {
     stop("\nYou must supply either x or mat but not both.")
   }
@@ -490,39 +481,33 @@ an.parallel <- function(x = NA, iterations = 0, centile = 0, seed = 0,
     }
   }
   
-  ##### Si  es matriz de datos entonces calcula la correlaci?n
-     
   if (!is.na(x[[1]][1])) {
-    N <- length(as.matrix(x)[, 1]) #Numero de individuos
+    N <- length(as.matrix(x)[, 1]) 
     if (!is.na(n)) {
       warning("\nThe n argument is only for use with the mat argument. Ignoring n argument.")
     }
     
-    R <- cor(x) #matriz de correlaci?n
+    R <- cor(x) 
     cat("\nUsing eigendecomposition of correlation matrix.")
   }
   
-  #se requiere el numero de observaciones para una matriz de correlacion, verifica esto
-  
   if (!is.na(mat[[1]][1])) {
     if (!is.na(mat[[1]][1]) & is.na(n)) {
       stop("\nYou must also provide the sample size when using the matrix argument.")
     }
     
     
-    N <- n #numero de observaciones
-    R <- mat #matriz de correlacion
+    N <- n 
+    R <- mat 
     cat("\nUsing eigendecomposition of provided correlation matrix.")
   }
   
-  centile <- round(centile) #centile de trabajo
+  centile <- round(centile) 
   
   if (centile > 99 | centile < 0) {
     stop("\nYou must specify a centile value between 1 and 99.\n(Specifying centile 0 will use the mean.)")
   }
   
-  ##Procedimiento para calcular los valores propios de las matrices de correlacion
-  ## si se desea una analisis de componentes principales
   eigenvalues <- eigen(R, only.values = TRUE, EISPACK = FALSE)[[1]]
   
   Ev <- eigenvalues
@@ -531,40 +516,27 @@ an.parallel <- function(x = NA, iterations = 0, centile = 0, seed = 0,
   Model <- "Component"
   Models <- "Components"
     
-  # numero de iteraciones de conjuntos de datos aleatorios
   if (iterations < 1) {
     iterations <- 30 * P
   }
   
-  
-  #matriz para los Eigenvalores simulados
   SimEvs <- matrix(NA, iterations, P)
   
-  
-  ## genera los valores simulados por el numero de iteraciones
   for (k in 1:iterations) {
     
-    #matriz para simulaciones
     Sim <- matrix(NA, N, P)
     
-    ##semilla para generar aleatorios
     if (seed != 0) {
       set.seed(seed * k)
     }
     
-    ## La matriz con los numeros aleatorios de una normal
-    
     Sim <- matrix(rnorm(N * P), N, P)
-    
-    ## eigen valores para los valores simulados
-    
+  
     eigenvalues <- eigen(cor(Sim), only.values = TRUE, EISPACK = FALSE)[[1]]
     Evs <- eigenvalues
     SimEvs[k, ] <- Evs
   }
   
-  #muestra la tabla con los valores ajustados y los componentes.
-  
   cat("\n\nResults of Horn's Parallel Analysis for ", model, 
       " retention\n", sep = "")
   if (iterations == 1) {
@@ -598,24 +570,20 @@ an.parallel <- function(x = NA, iterations = 0, centile = 0, seed = 0,
   cat("--------------------------------------------------", 
       "\n")
   
-  ## vector de Na's del numero de variables
   RndEv = c(1:P) * NA
   
-  ##completa el vector anterior los cuantiles de los valores simulados es una lista
   if (centile > 0) {
     for (p in 1:P) {
       RndEv[[p]] <- quantile(SimEvs[, p], probs = centile/100)[[1]]
     }
   }
   
-  ## si el centil elegido es cero entonces completa con la media
   if (centile == 0) {
     for (p in 1:P) {
       RndEv[[p]] <- mean(SimEvs[, p])
     }
   }
   
-  ### se detiene si no recibe componentes
   if (Ev[[1]] < 1 | RndEv[[1]] < 1) {
     cat("No components passed.", "\n")
     cat("--------------------------------------------------", 
@@ -623,16 +591,14 @@ an.parallel <- function(x = NA, iterations = 0, centile = 0, seed = 0,
     stop
   }
   
-  ##vector de sesgo
   Bias <- rep(0, P)
-  ##vector de eigenvalores ajustados
   AdjEv <- rep(1, P)
   
   for (p in 1:P) {
     Bias[p] <- RndEv[p] - 1
     AdjEv[p] <- Ev[[p]] - Bias[p]
   }
-  ##vector y
+
   y <- NA
   
   for (x in 1:P) {
